@@ -556,7 +556,7 @@ class ViewRequestFactoryTestMixin(object):
         resp = self.post(
             user=user, data=data, add_session=add_session, kwargs=kwargs,
             ajax=ajax)
-        if not ajax:
+        if not ajax or to:
             if next_url:
                 next_url = '?next={0}'.format(next_url)
             redirect_url = '{0}{1}'.format(to, next_url)
@@ -566,10 +566,9 @@ class ViewRequestFactoryTestMixin(object):
         return resp
 
     def redirects(self, to, next_url='', user=None, add_session=False,
-                  kwargs=None, msg=None, data=None):
+                  kwargs=None, msg=None):
         """Checks for redirects from a GET request."""
-        resp = self.get(user=user, add_session=add_session, kwargs=kwargs,
-                        data=data)
+        resp = self.get(user=user, add_session=add_session, kwargs=kwargs)
         if next_url:
             next_url = '?next={0}'.format(next_url)
         redirect_url = '{0}{1}'.format(to, next_url)
